@@ -1,7 +1,7 @@
 /*************************************************************************/
 /* Copyright (c) 2004                                                    */
 /* Daniel Sleator, David Temperley, and John Lafferty                    */
-/* Copyright (c) 2013 Linas Vepstas                                      */
+/* Copyright (c) 2013,2014 Linas Vepstas                                 */
 /* All rights reserved                                                   */
 /*                                                                       */
 /* Use of the link grammar parsing system is subject to the terms of the */
@@ -27,11 +27,12 @@
 typedef struct Table_connector_s Table_connector;
 struct Table_connector_s
 {
-	short            lw, rw;
-	Connector        *le, *re;
-	unsigned short   cost;
-	s64              count;
 	Table_connector  *next;
+	Connector        *le, *re;
+	s64              count;
+	short            lw, rw;
+	unsigned short   cost; /* Cost, here and below, is actually the
+	                        * null-count being considered. */
 };
 
 struct count_context_s
@@ -41,15 +42,15 @@ struct count_context_s
 	char ** effective_dist; 
 #endif /* USE_FAT_LINKAGES */
 	Word *  local_sent;
-	int     null_block;
+	/* int     null_block; */ /* not used, always 1 */
 	bool    islands_ok;
 	bool    null_links;
+	bool    exhausted;
+	int     checktimer;  /* Avoid excess system calls */
 	int     table_size;
 	int     log2_table_size;
 	Table_connector ** table;
 	Resources current_resources;
-	bool    exhausted;
-	int     checktimer;  /* Avoid excess system calls */
 };
 
 static void free_table(count_context_t *ctxt)
@@ -263,8 +264,9 @@ find_table_pointer(count_context_t *ctxt,
 	unsigned int h = pair_hash(ctxt->log2_table_size,lw, rw, le, re, cost);
 	t = ctxt->table[h];
 	for (; t != NULL; t = t->next) {
-		if ((t->lw == lw) && (t->rw == rw) && (t->le == le) && (t->re == re)
-			&& (t->cost == cost))  return t;
+		if ((t->lw == lw) && (t->rw == rw)
+		    && (t->le == le) && (t->re == re)
+		    && (t->cost == cost))  return t;
 	}
 
 	/* Create a new connector only if resources are exhausted.
@@ -314,38 +316,31 @@ static void table_update(count_context_t *ctxt, int lw, int rw,
  * with a count value of 0.
  */
 static s64 pseudocount(count_context_t * ctxt,
-                       int lw, int rw, Connector *le, Connector *re, unsigned int cost)
+                       int lw, int rw, Connector *le, Connector *re,
+                       unsigned int cost)
 {
-	s64 count;
-	count = table_lookup(ctxt, lw, rw, le, re, cost);
+	s64 count = table_lookup(ctxt, lw, rw, le, re, cost);
 	if (count == 0) return 0; else return 1;
 }
 
-static s64 do_count(match_context_t *mchxt, 
+static s64 do_count(fast_matcher_t *mchxt, 
                     count_context_t *ctxt,
                     int lw, int rw,
                     Connector *le, Connector *re, int null_count)
 {
 	s64 total;
 	int start_word, end_word, w;
-	s64 leftcount, rightcount, pseudototal;
-	bool Lmatch, Rmatch;
-	unsigned int lcost, rcost;
-
-	Match_node * m, *m1;
 	Table_connector *t;
 
 	if (null_count < 0) return 0;  /* can this ever happen?? */
 
 	t = find_table_pointer(ctxt, lw, rw, le, re, null_count);
 
-	if (t == NULL) {
-		/* Create the table entry with a tentative null count of 0. 
-	    * This count must be updated before we return. */
-		t = table_store(ctxt, lw, rw, le, re, null_count, 0);
-	} else {
-		return t->count;
-	}
+	if (t) return t->count;
+
+	/* Create the table entry with a tentative null count of 0. 
+	 * This count must be updated before we return. */
+	t = table_store(ctxt, lw, rw, le, re, null_count, 0);
 
 	if (rw == 1+lw)
 	{
@@ -368,8 +363,10 @@ static s64 do_count(match_context_t *mchxt,
 		{
 			/* If we don't allow islands (a set of words linked together
 			 * but separate from the rest of the sentence) then the
-			 * null_count of skipping n words is just n */
-			if (null_count == ((rw-lw-1) + ctxt->null_block-1)/ctxt->null_block)
+			 * null_count of skipping n words is just n. */
+			/* null_block is always 1 these days. */
+			/* if (null_count == ((rw-lw-1) + ctxt->null_block-1) / ctxt->null_block) */
+			if (null_count == (rw-lw-1))
 			{
 				/* If null_block=4 then the null_count of
 				   1,2,3,4 nulls is 1; and 5,6,7,8 is 2 etc. */
@@ -391,8 +388,8 @@ static s64 do_count(match_context_t *mchxt,
 		else
 		{
 			Disjunct * d;
-			total = 0;
-			w = lw+1;
+			s64 total = 0;
+			int w = lw + 1;
 			for (d = ctxt->local_sent[w].d; d != NULL; d = d->next)
 			{
 				if (d->left == NULL)
@@ -428,15 +425,21 @@ static s64 do_count(match_context_t *mchxt,
 
 	for (w = start_word; w < end_word; w++)
 	{
+		Match_node *m, *m1;
 		m1 = m = form_match_list(mchxt, w, le, lw, re, rw);
 		for (; m != NULL; m = m->next)
 		{
+			unsigned int lcost, rcost;
 			unsigned int null_count_p1;
 			Disjunct * d;
 			d = m->d;
 			null_count_p1 = null_count + 1; /* avoid gcc warning: unsafe loop opt */
 			for (lcost = 0; lcost < null_count_p1; lcost++)
 			{
+				bool Lmatch, Rmatch;
+				s64 leftcount = 0, rightcount = 0;
+				s64 pseudototal;
+
 				rcost = null_count - lcost;
 				/* Now lcost and rcost are the costs we're assigning
 				 * to those parts respectively */
@@ -448,7 +451,6 @@ static s64 do_count(match_context_t *mchxt,
 				Rmatch = (d->right != NULL) && (re != NULL) && 
 				         do_match(ctxt, d->right, re, w, rw);
 
-				rightcount = leftcount = 0;
 				if (Lmatch)
 				{
 					leftcount = pseudocount(ctxt, lw, w, le->next, d->left->next, lcost);
@@ -494,14 +496,15 @@ static s64 do_count(match_context_t *mchxt,
 						if (d->right->multi && re->multi) rightcount += do_count(mchxt, ctxt, w, rw, d->right, re, rcost);
 					}
 
-					total += leftcount*rightcount;  /* total number where links are used on both sides */
+					/* Total number where links are used on both sides */
+					total += leftcount*rightcount;
 
 					if (leftcount > 0) {
-						/* evaluate using the left match, but not the right */
+						/* Evaluate using the left match, but not the right */
 						total += leftcount * do_count(mchxt, ctxt, w, rw, d->right, re, rcost);
 					}
 					if ((le == NULL) && (rightcount > 0)) {
-						/* evaluate using the right match, but not the left */
+						/* Evaluate using the right match, but not the left */
 						total += rightcount * do_count(mchxt, ctxt, lw, w, le, d->left, lcost);
 					}
 
@@ -525,19 +528,36 @@ static s64 do_count(match_context_t *mchxt,
 
 /** 
  * Returns the number of ways the sentence can be parsed with the
- * specified null count. Assumes that the hash table has already been
- * initialized, and is freed later. The "null_count" here is the
- * number of words that are allowed to have no links to them.
+ * specified null count. Assumes that the faster matcher and the count
+ * context have already been initialized, and are freed later. The
+ * "null_count" argument is the number of words that are allowed to
+ * have no links to them.
+ *
+ * This the full-fledged parser, but it only 'counts', in order to
+ * avoid an explosion of allocated memory structures to hold each
+ * possible parse.  Thus, to see an 'actual' parse, a second pass
+ * must be made, with build_parse_set(), to get actual parse structures.
+ *
+ * The work is split up this way for two reasons:
+ * 1) A given sentence may have thousands of parses, and the user is
+ *    interested in only a few.
+ * 2) A given sentence may have billions of parses, in which case,
+ *    allocating for each would blow out RAM.
+ * So, basically, its good to know how many parses to expect, before
+ * starting to allocate parse structures.
+ *
+ * The count returned here is mean to be completely accurate; it is
+ * not an approximation!
  */
 s64 do_parse(Sentence sent,
-             match_context_t *mchxt,
+             fast_matcher_t *mchxt,
              count_context_t *ctxt,
              int null_count, Parse_Options opts)
 {
 	s64 total;
 
 	ctxt->current_resources = opts->resources;
-	ctxt->exhausted = resources_exhausted(ctxt->current_resources);
+	ctxt->exhausted = false;
 	ctxt->checktimer = 0;
 	ctxt->local_sent = sent->word;
 #ifdef USE_FAT_LINKAGES
@@ -547,7 +567,7 @@ s64 do_parse(Sentence sent,
 
 	/* consecutive blocks of this many words are considered as
 	 * one null link. */
-	ctxt->null_block = 1;
+	/* ctxt->null_block = 1; */
 	ctxt->islands_ok = opts->islands_ok;
 
 	total = do_count(mchxt, ctxt, -1, sent->length, NULL, NULL, null_count+1);
@@ -605,7 +625,7 @@ static int x_prune_match(count_context_t *ctxt,
  * links.  Returns 1 if it can, and it's not been marked, and returns
  * 2 if it can and it has been marked.
  */
-static int region_valid(match_context_t *mchxt, count_context_t *ctxt,
+static int region_valid(fast_matcher_t *mchxt, count_context_t *ctxt,
                         int lw, int rw, Connector *le, Connector *re)
 {
 	Disjunct * d;
@@ -677,7 +697,7 @@ static int region_valid(match_context_t *mchxt, count_context_t *ctxt,
  * this region itself is not valid, then this fact will be recorded
  * in the table, and nothing else happens.
  */
-static void mark_region(match_context_t *mchxt, count_context_t *ctxt,
+static void mark_region(fast_matcher_t *mchxt, count_context_t *ctxt,
                         int lw, int rw, Connector *le, Connector *re)
 {
 
@@ -827,7 +847,7 @@ void conjunction_prune(Sentence sent, count_context_t *ctxt, Parse_Options opts)
 		}
 	}
 
-	match_context_t *mchxt = alloc_fast_matcher(sent);
+	fast_matcher_t *mchxt = alloc_fast_matcher(sent);
 	ctxt->local_sent = sent->word;
 	ctxt->null_links = (opts->min_null_count > 0);
 	/*
