@@ -92,7 +92,7 @@ static Disjunct * glom_comma_connector(Disjunct * d)
  * use a neither.  (Not the case with "or".)  If necessary=FALSE, then
  * duplication is done, otherwise it isn't
  */
-static Disjunct * glom_aux_connector(Disjunct * d, int label, int necessary)
+static Disjunct * glom_aux_connector(Disjunct * d, int label, bool necessary)
 {
 	Disjunct * d_list, * d1, * d2;
 	Connector * c, * c1, *c2;
@@ -186,7 +186,7 @@ static Disjunct * special_disjunct(int label, int dir, const char *cs, const cha
  */
 static void construct_comma(Sentence sent)
 {
-	int w;
+	size_t w;
 	for (w=0; w<sent->length-1; w++) {
 		if ((strcmp(sent->word[w].alternatives[0], ",")==0) && sent->is_conjunction[w+1]) {
 			sent->word[w].d = catenate_disjuncts(special_disjunct(COMMA_LABEL,'+',"", ","), sent->word[w].d);
@@ -197,13 +197,13 @@ static void construct_comma(Sentence sent)
 
 
 /** Returns TRUE if one of the words in the sentence is s */
-static int sentence_contains(Sentence sent, const char * s)
+static bool sentence_contains(Sentence sent, const char * s)
 {
-	int w;
+	size_t w;
 	for (w=0; w<sent->length; w++) {
-		if (strcmp(sent->word[w].alternatives[0], s) == 0) return TRUE;
+		if (strcmp(sent->word[w].alternatives[0], s) == 0) return true;
 	}
-	return FALSE;
+	return false;
 }
 
 /**
@@ -217,7 +217,7 @@ Screw it. This code is obsolete, and will be removed before long.
 
 static void construct_either(Sentence sent)
 {
-	int w;
+	size_t w;
 	if (!sentence_contains(sent, "either")) return;
 	for (w=0; w<sent->length; w++) {
 		if (strcmp(sent->word[w].alternatives[0], "either") != 0) continue;
@@ -229,13 +229,13 @@ static void construct_either(Sentence sent)
 	for (w=0; w<sent->length; w++) {
 		if (strcmp(sent->word[w].alternatives[0], "or") != 0) continue;
 		sent->word[w].d = glom_aux_connector
-						  (sent->word[w].d, EITHER_LABEL, FALSE);
+						  (sent->word[w].d, EITHER_LABEL, false);
 	}
 }
 
 static void construct_neither(Sentence sent)
 {
-	int w;
+	size_t w;
 	if (!sentence_contains(sent, "neither")) {
 		/* I don't see the point removing disjuncts on "nor".  I
 		   Don't know why I did this.  What's the problem keeping the
@@ -259,13 +259,13 @@ static void construct_neither(Sentence sent)
 	for (w=0; w<sent->length; w++) {
 		if (strcmp(sent->word[w].alternatives[0], "nor") != 0) continue;
 		sent->word[w].d = glom_aux_connector
-						  (sent->word[w].d, NEITHER_LABEL, TRUE);
+						  (sent->word[w].d, NEITHER_LABEL, true);
 	}
 }
 
 static void construct_notonlybut(Sentence sent)
 {
-	int w;
+	size_t w;
 	Disjunct *d;
 	if (!sentence_contains(sent, "not")) {
 		return;
@@ -300,14 +300,14 @@ static void construct_notonlybut(Sentence sent)
 	for (w=0; w<sent->length; w++) {
 		if (strcmp(sent->word[w].alternatives[0], "but") != 0) continue;
 		sent->word[w].d = glom_aux_connector
-						  (sent->word[w].d, NOT_LABEL, FALSE);
+						  (sent->word[w].d, NOT_LABEL, false);
 		/* The above line use to have a TRUE in it */
 	}
 }
 
 static void construct_both(Sentence sent)
 {
-	int w;
+	size_t w;
 	if (!sentence_contains(sent, "both")) return;
 	for (w=0; w<sent->length; w++) {
 		if (strcmp(sent->word[w].alternatives[0], "both") != 0) continue;
@@ -318,7 +318,7 @@ static void construct_both(Sentence sent)
 
 	for (w=0; w<sent->length; w++) {
 		if (strcmp(sent->word[w].alternatives[0], "and") != 0) continue;
-		sent->word[w].d = glom_aux_connector(sent->word[w].d, BOTH_LABEL, FALSE);
+		sent->word[w].d = glom_aux_connector(sent->word[w].d, BOTH_LABEL, false);
 	}
 }
 
