@@ -48,9 +48,9 @@ static void initialize_set_of_links_starting_bounded_domain(pp_knowledge *k)
     {
       domain_of_rule = k->bounded_rules[i].domain;
       for (j=0; (d=(k->starting_link_lookup_table[j].domain))!=-1; j++)
-	if (d==domain_of_rule)
-	  pp_linkset_add(k->set_of_links_starting_bounded_domain,
-		      k->starting_link_lookup_table[j].starting_link);
+        if (d==domain_of_rule)
+          pp_linkset_add(k->set_of_links_starting_bounded_domain,
+                      k->starting_link_lookup_table[j].starting_link);
     }
 }
 
@@ -93,7 +93,7 @@ static void read_starting_link_table(pp_knowledge *k)
 }
 
 static pp_linkset *read_link_set(pp_knowledge *k,
-				 const char *label, String_set *ss)
+                                 const char *label, String_set *ss)
 {
   /* read link set, marked by label in knowledge file, into a set of links
      whose handle is returned. Return NULL if link set not defined in file,
@@ -109,7 +109,7 @@ static pp_linkset *read_link_set(pp_knowledge *k,
   ls = pp_linkset_open(n_strings);
   for (i=0; i<n_strings; i++)
     pp_linkset_add(ls,
-		   string_set_add(pp_lexer_get_next_token_of_label(k->lt),ss));
+                   string_set_add(pp_lexer_get_next_token_of_label(k->lt),ss));
   return ls;
 }
 
@@ -139,29 +139,6 @@ static void free_link_sets(pp_knowledge *k)
   pp_linkset_close(k->left_domain_starter_links);
 }
 
-static void read_connected_rule(pp_knowledge *k, const char *label)
-{
-  /* This is a degenerate class of rules: either a single rule asserting
-     connectivity is there, or it isn't. The only information in the
-     rule (besides its presence) is the error message to display if
-     the rule is violated */
-  k->connected_rules = (pp_rule *) xalloc (sizeof(pp_rule));
-  if (!pp_lexer_set_label(k->lt, label))
-    {
-      k->connected_rules[0].msg=0;  /* rule not there */
-      if (1 < verbosity) printf("PP warning: Not using 'link is connected' rule\n");
-      return;
-    }
-  if (pp_lexer_count_tokens_of_label(k->lt)>1)
-  {
-    prt_error("Fatal Error: post_process(): Invalid syntax in %s", label);
-    exit(1);
-  }
-  k->connected_rules[0].msg =
-    string_set_add(pp_lexer_get_next_token_of_label(k->lt), k->string_set);
-}
-
-
 static void read_form_a_cycle_rules(pp_knowledge *k, const char *label)
 {
   size_t n_commas, n_tokens;
@@ -191,7 +168,7 @@ static void read_form_a_cycle_rules(pp_knowledge *k, const char *label)
       lsHandle = pp_linkset_open(n_tokens);
       for (i=0; i<n_tokens; i++)
           pp_linkset_add(lsHandle,string_set_add(tokens[i], k->string_set));
-      k->form_a_cycle_rules[r].link_set=lsHandle;
+      k->form_a_cycle_rules[r].link_set = lsHandle;
 
       /* read error message */
       tokens = pp_lexer_get_next_group_of_tokens_of_label(k->lt, &n_tokens);
@@ -200,11 +177,13 @@ static void read_form_a_cycle_rules(pp_knowledge *k, const char *label)
          prt_error("Fatal Error: post_process: Invalid syntax (rule %zu of %s)",r+1,label);
          exit(1);
       }
-      k->form_a_cycle_rules[r].msg=string_set_add(tokens[0],k->string_set);
+      k->form_a_cycle_rules[r].msg = string_set_add(tokens[0], k->string_set);
+      k->form_a_cycle_rules[r].use_count = 0;
     }
 
   /* sentinel entry */
   k->form_a_cycle_rules[k->n_form_a_cycle_rules].msg = 0;
+  k->form_a_cycle_rules[k->n_form_a_cycle_rules].use_count = 0;
 }
 
 static void read_bounded_rules(pp_knowledge *k, const char *label)
@@ -223,7 +202,7 @@ static void read_bounded_rules(pp_knowledge *k, const char *label)
   k->bounded_rules = (pp_rule*) xalloc ((1+k->n_bounded_rules)*sizeof(pp_rule));
   for (r=0; r<k->n_bounded_rules; r++)
     {
-      /* read domain */	
+      /* read domain */
       tokens = pp_lexer_get_next_group_of_tokens_of_label(k->lt, &n_tokens);
       if (n_tokens!=1)
       {
@@ -240,14 +219,16 @@ static void read_bounded_rules(pp_knowledge *k, const char *label)
         exit(1);
       }
       k->bounded_rules[r].msg = string_set_add(tokens[0], k->string_set);
+      k->bounded_rules[r].use_count = 0;
     }
 
   /* sentinel entry */
   k->bounded_rules[k->n_bounded_rules].msg = 0;
+  k->bounded_rules[k->n_bounded_rules].use_count = 0;
 }
 
 static void read_contains_rules(pp_knowledge *k, const char *label,
-				pp_rule **rules, size_t *nRules)
+                                pp_rule **rules, size_t *nRules)
 {
   /* Reading the 'contains_one_rules' and reading the
      'contains_none_rules' into their respective arrays */
@@ -291,22 +272,23 @@ static void read_contains_rules(pp_knowledge *k, const char *label,
         "Fatal Error: post_process: Invalid syntax in %s (rule %zu)", label, r+1);
 
       (*rules)[r].msg = string_set_add(tokens[0], k->string_set);
+      (*rules)[r].use_count = 0;
     }
 
   /* sentinel entry */
   (*rules)[*nRules].msg = 0;
+  (*rules)[*nRules].use_count = 0;
 }
 
 
 static void read_rules(pp_knowledge *k)
 {
   read_form_a_cycle_rules(k, "FORM_A_CYCLE_RULES");
-  read_connected_rule(k, "CONNECTED_RULES");
   read_bounded_rules(k,  "BOUNDED_RULES");
   read_contains_rules(k, "CONTAINS_ONE_RULES" ,
-		      &(k->contains_one_rules), &(k->n_contains_one_rules));
+                      &(k->contains_one_rules), &(k->n_contains_one_rules));
   read_contains_rules(k, "CONTAINS_NONE_RULES",
-		      &(k->contains_none_rules), &(k->n_contains_none_rules));
+                      &(k->contains_none_rules), &(k->n_contains_none_rules));
 }
 
 static void free_rules(pp_knowledge *k)
@@ -314,22 +296,23 @@ static void free_rules(pp_knowledge *k)
   size_t r;
   size_t rs = sizeof(pp_rule);
   pp_rule *rule;
-  for (r=0; k->contains_one_rules[r].msg!=0; r++) {
+  for (r=0; k->contains_one_rules[r].msg!=0; r++)
+  {
     rule = &(k->contains_one_rules[r]);    /* shorthand */
     xfree((void*) rule->link_array, (1+rule->link_set_size)*sizeof(char*));
     pp_linkset_close(rule->link_set);
   }
-  for (r=0; k->contains_none_rules[r].msg!=0; r++) {
+  for (r=0; k->contains_none_rules[r].msg!=0; r++)
+  {
     rule = &(k->contains_none_rules[r]);   /* shorthand */
     xfree((void *)rule->link_array, (1+rule->link_set_size)*sizeof(char*));
     pp_linkset_close(rule->link_set);
   }
 
-  for (r=0; r<k->n_form_a_cycle_rules; r++)
+  for (r = 0; r < k->n_form_a_cycle_rules; r++)
     pp_linkset_close(k->form_a_cycle_rules[r].link_set);
   xfree((void*)k->bounded_rules,           rs*(1+k->n_bounded_rules));
-  xfree((void*)k->connected_rules,         rs);
-  xfree((void*)k->form_a_cycle_rules, rs*(1+k->n_form_a_cycle_rules));
+  xfree((void*)k->form_a_cycle_rules,      rs*(1+k->n_form_a_cycle_rules));
   xfree((void*)k->contains_one_rules,      rs*(1+k->n_contains_one_rules));
   xfree((void*)k->contains_none_rules,     rs*(1+k->n_contains_none_rules));
 }
@@ -361,7 +344,7 @@ void pp_knowledge_close(pp_knowledge *k)
 {
   /* clear the memory taken up by k */
   xfree((void*)k->starting_link_lookup_table,
-	((1+k->nStartingLinks)*sizeof(StartingLinkAndDomain)));
+        ((1+k->nStartingLinks)*sizeof(StartingLinkAndDomain)));
   free_link_sets(k);
   free_rules(k);
   pp_linkset_close(k->set_of_links_starting_bounded_domain);
@@ -370,6 +353,3 @@ void pp_knowledge_close(pp_knowledge *k)
   xfree((void*)k, sizeof(pp_knowledge));
 }
 
-
-
-
