@@ -29,7 +29,7 @@
 
 void free_deletable(Sentence sent)
 {
-	int w;
+	size_t w;
 	if (sent->dptr != NULL)
 	{
 		for (w = 0; w <= sent->length; w++)
@@ -43,14 +43,14 @@ void free_deletable(Sentence sent)
 }
 
 /**
- *  Returns true if the range lw...rw inclusive contains a conjunction 
+ *  Returns true if the range lw...rw inclusive contains a conjunction
  */
-static int conj_in_range(Sentence sent, int lw, int rw)
+static bool conj_in_range(Sentence sent, int lw, int rw)
 {
 	for (;lw < rw+1; lw++) {
-		if (sent->is_conjunction[lw]) return TRUE;
+		if (sent->is_conjunction[lw]) return true;
 	}
-	return FALSE;
+	return false;
 }
 
 
@@ -67,7 +67,7 @@ static int conj_in_range(Sentence sent, int lw, int rw)
  * words "either", "neither", "both", "not" and "not only" are all
  * deletable.
  */
-void build_deletable(Sentence sent, int has_conjunction)
+void build_deletable(Sentence sent, bool has_conjunction)
 {
 	int i,j,k;
 
@@ -85,15 +85,15 @@ void build_deletable(Sentence sent, int has_conjunction)
 		{
 			if (j == i+1)
 			{
-				sent->deletable[i][j] = TRUE;
+				sent->deletable[i][j] = true;
 			}
 			else if (sent->null_links)
 			{
-				sent->deletable[i][j] = TRUE;
+				sent->deletable[i][j] = true;
 			}
 			else if (!has_conjunction)
 			{
-				sent->deletable[i][j] = FALSE;
+				sent->deletable[i][j] = false;
 			}
 			else if ((j > i + 2) && (sent->is_conjunction[i+1] ||
 								 sent->is_conjunction[j-1] ||
@@ -102,7 +102,7 @@ void build_deletable(Sentence sent, int has_conjunction)
 								 (strcmp(",",sent->word[j-1].alternatives[0]) == 0 &&
 								 conj_in_range(sent, j, sent->length - 1))))
 			{
-				sent->deletable[i][j] = TRUE;
+				sent->deletable[i][j] = true;
 			}
 			else if (j > i)
 			{
@@ -120,7 +120,7 @@ void build_deletable(Sentence sent, int has_conjunction)
 			}
 			else
 			{
-				sent->deletable[i][j] = FALSE;
+				sent->deletable[i][j] = false;
 			}
 		}
 	}
@@ -128,7 +128,7 @@ void build_deletable(Sentence sent, int has_conjunction)
 
 void free_effective_dist(Sentence sent)
 {
-	int w;
+	size_t w;
 	if (sent->effective_dist != NULL) {
 		for (w=0; w<sent->length; w++) {
 			xfree((char *)sent->effective_dist[w],sizeof(char)*(sent->length+1));
@@ -157,9 +157,9 @@ void free_effective_dist(Sentence sent)
  * Just as deletable[i][j] is constructed for j=N_words (which is one
  * off the end of the sentence) we do that for effective_dist[][].
  */
-void build_effective_dist(Sentence sent, int has_conjunction)
+void build_effective_dist(Sentence sent, bool has_conjunction)
 {
-	int i, j, diff;
+	size_t i, j, diff;
 
 	free_effective_dist(sent);
 	sent->effective_dist = (char **) xalloc((sent->length)*sizeof(char *));
@@ -231,7 +231,7 @@ void build_effective_dist(Sentence sent, int has_conjunction)
  */
 static void install_fat_connectors(Sentence sent)
 {
-	int i;
+	size_t i;
 	for (i=0; i<sent->length; i++) {
 		if (sent->is_conjunction[i]) {
 			sent->word[i].d = catenate_disjuncts(sent->word[i].d,
@@ -247,7 +247,7 @@ static void install_fat_connectors(Sentence sent)
 	}
 }
 
-static void 
+static void
 set_connector_list_length_limit(count_context_t * ctxt,
                                 Connector *c,
                                 Connector_set *conset,
@@ -266,7 +266,7 @@ set_connector_list_length_limit(count_context_t * ctxt,
 	}
 }
 
-static void 
+static void
 set_connector_length_limits(Sentence sent, count_context_t * ctxt,
                             Parse_Options opts)
 {
@@ -298,13 +298,13 @@ set_connector_length_limits(Sentence sent, count_context_t * ctxt,
  */
 int sentence_contains_conjunction(Sentence sent)
 {
-	int w;
-	if (NULL == sent->is_conjunction) return FALSE;
+	size_t w;
+	if (NULL == sent->is_conjunction) return false;
 
 	for (w=0; w<sent->length; w++) {
-		if (sent->is_conjunction[w]) return TRUE;
+		if (sent->is_conjunction[w]) return true;
 	}
-	return FALSE;
+	return false;
 }
 
 /**
@@ -315,6 +315,7 @@ void prepare_to_parse(Sentence sent, Parse_Options opts)
 {
 	size_t i;
 	bool has_conjunction;
+	count_context_t * ctxt;
 
 	build_sentence_disjuncts(sent, opts->disjunct_cost);
 	if (verbosity > 2) {
@@ -345,7 +346,7 @@ void prepare_to_parse(Sentence sent, Parse_Options opts)
 	}
 	else
 	{
-		has_conjunction = FALSE;
+		has_conjunction = false;
 	}
 
 	/* The deletable region depends on whether null links are in use;
@@ -413,7 +414,7 @@ void prepare_to_parse(Sentence sent, Parse_Options opts)
 
 #else
 
-static void 
+static void
 set_connector_list_length_limit(Connector *c,
                                 Connector_set *conset,
                                 int short_len,
@@ -431,7 +432,7 @@ set_connector_list_length_limit(Connector *c,
 	}
 }
 
-static void 
+static void
 set_connector_length_limits(Sentence sent, Parse_Options opts)
 {
 	size_t i;
@@ -478,12 +479,12 @@ void prepare_to_parse(Sentence sent, Parse_Options opts)
 	}
 
 	set_connector_length_limits(sent, opts);
-	pp_and_power_prune(sent, RUTHLESS, opts);
+	pp_and_power_prune(sent, opts);
 }
 
 int sentence_contains_conjunction(Sentence sent)
 {
-	return FALSE;
+	return false;
 }
 
 #endif /* USE_FAT_LINKAGES */
