@@ -34,7 +34,7 @@
 
 static void
 set_centers(const Linkage linkage, int center[],
-            Boolean print_word_0, int N_words_to_print)
+            bool print_word_0, int N_words_to_print)
 {
 	int i, len, tot;
 
@@ -272,7 +272,9 @@ build_linkage_postscript_string(const Linkage linkage,
 {
 	int link, i,j;
 	int d;
-	int print_word_0 = 0, print_word_N = 0, N_wall_connectors, suppressor_used;
+	int N_wall_connectors;
+	bool print_word_0 = false, print_word_N = false;
+	bool suppressor_used;
 #ifdef USE_FAT_LINKAGES
 	Sublinkage *sublinkage = &(linkage->sublinkage[linkage->current]);
 #else
@@ -289,31 +291,31 @@ build_linkage_postscript_string(const Linkage linkage,
 
 	N_wall_connectors = 0;
 	if (dict->left_wall_defined) {
-		suppressor_used = FALSE;
+		suppressor_used = false;
 		if (!display_walls)
 			for (j=0; j<N_links; j++) {
 				if (ppla[j]->lw == 0) {
 					if (ppla[j]->rw == linkage->num_words-1) continue;
 					N_wall_connectors ++;
 					if (strcmp(ppla[j]->lc->string, LEFT_WALL_SUPPRESS)==0) {
-						suppressor_used = TRUE;
+						suppressor_used = true;
 					}
 				}
 			}
 		print_word_0 = (((!suppressor_used) && (N_wall_connectors != 0))
 						|| (N_wall_connectors > 1) || display_walls);
 	} else {
-		print_word_0 = TRUE;
+		print_word_0 = true;
 	}
 
 	N_wall_connectors = 0;
 	if (dict->right_wall_defined) {
-		suppressor_used = FALSE;
+		suppressor_used = false;
 		for (j=0; j<N_links; j++) {
 			if (ppla[j]->rw == linkage->num_words-1) {
 				N_wall_connectors ++;
 				if (strcmp(ppla[j]->lc->string, RIGHT_WALL_SUPPRESS)==0){
-					suppressor_used = TRUE;
+					suppressor_used = true;
 				}
 			}
 		}
@@ -321,7 +323,7 @@ build_linkage_postscript_string(const Linkage linkage,
 						|| (N_wall_connectors > 1) || display_walls);
 	}
 	else {
-		print_word_N = TRUE;
+		print_word_N = true;
 	}
 
 	if (print_word_0) d=0; else d=1;
@@ -399,8 +401,9 @@ linkage_print_diagram_ctxt(const Linkage linkage,
 	unsigned int i, j, k, cl, cr, row, top_row, top_row_p1;
 	const char *s;
 	char *t;
-	bool print_word_0 = 0, print_word_N = 0;
-	int N_wall_connectors, suppressor_used;
+	bool print_word_0 = false, print_word_N = false;
+	int N_wall_connectors;
+	bool suppressor_used;
 	int center[linkage->num_words+1];
 	unsigned int line_len, link_length;
 #ifdef USE_FAT_LINKAGES
@@ -425,7 +428,7 @@ linkage_print_diagram_ctxt(const Linkage linkage,
 	N_wall_connectors = 0;
 	if (dict->left_wall_defined)
 	{
-		suppressor_used = FALSE;
+		suppressor_used = false;
 		if (!display_walls)
 		{
 			for (j=0; j<N_links; j++)
@@ -436,7 +439,7 @@ linkage_print_diagram_ctxt(const Linkage linkage,
 					N_wall_connectors ++;
 					if (0 == strcmp(ppla[j]->lc->string, LEFT_WALL_SUPPRESS))
 					{
-						suppressor_used = TRUE;
+						suppressor_used = true;
 					}
 				}
 			}
@@ -446,14 +449,14 @@ linkage_print_diagram_ctxt(const Linkage linkage,
 	}
 	else
 	{
-		print_word_0 = TRUE;
+		print_word_0 = true;
 	}
 
 	/* Do we want to print the right wall? */
 	N_wall_connectors = 0;
 	if (dict->right_wall_defined)
 	{
-		suppressor_used = FALSE;
+		suppressor_used = false;
 		for (j=0; j<N_links; j++)
 		{
 			if (ppla[j]->rw == linkage->num_words-1)
@@ -461,7 +464,7 @@ linkage_print_diagram_ctxt(const Linkage linkage,
 				N_wall_connectors ++;
 				if (0 == strcmp(ppla[j]->lc->string, RIGHT_WALL_SUPPRESS))
 				{
-					suppressor_used = TRUE;
+					suppressor_used = true;
 				}
 			}
 		}
@@ -470,7 +473,7 @@ linkage_print_diagram_ctxt(const Linkage linkage,
 	}
 	else
 	{
-		print_word_N = TRUE;
+		print_word_N = true;
 	}
 
 	N_words_to_print = linkage->num_words;
@@ -647,7 +650,7 @@ linkage_print_diagram_ctxt(const Linkage linkage,
 			/* print each row of the picture */
 			/* 'blank' is used solely to detect blank lines */
 			unsigned int mbcnt = 0;
-			Boolean blank = TRUE;
+			bool blank = true;
 
 			row = top_row - revrs;
 			k = start[row];
@@ -718,7 +721,7 @@ void linkage_free_senses(char * s)
 static const char * trailer(bool print_ps_header);
 static const char * header(bool print_ps_header);
 
-char * linkage_print_postscript(Linkage linkage, bool display_walls, bool print_ps_header)
+char * linkage_print_postscript(const Linkage linkage, bool display_walls, bool print_ps_header)
 {
 	char * ps, * qs;
 	int size;
@@ -1184,14 +1187,14 @@ struct tokenpos /* First position of the given token - to prevent duplicates */
 	int ai;
 };
 
-void print_sentence_word_alternatives(Sentence sent, Boolean debugprint,
+void print_sentence_word_alternatives(Sentence sent, bool debugprint,
      void (*display)(Dictionary, const char *), struct tokenpos * tokenpos)
 {
 	int wi;   /* Internal sentence word index */
 	int ai;   /* Index of a word alternative */
 	int sentlen = sent->length;        /* Shortened if there is a right-wall */
 	int first_sentence_word = 0;       /* Used for skipping a left-wall */
-	int word_split = FALSE;            /* !!word got split */
+	bool word_split = false;           /* !!word got split */
 
 	if (0 == sentlen)
 	{
@@ -1220,7 +1223,7 @@ void print_sentence_word_alternatives(Sentence sent, Boolean debugprint,
 		 * 2. A word containing more than one alternative. */
 		if (sentlen - first_sentence_word > 1)
 		{
-			word_split = TRUE;
+			word_split = true;
 		}
 		else
 		{
@@ -1234,7 +1237,7 @@ void print_sentence_word_alternatives(Sentence sent, Boolean debugprint,
 
 				if (NULL != w.alternatives[1])
 				{
-					word_split = TRUE;
+					word_split = true;
 					break;
 				}
 			}
@@ -1260,7 +1263,7 @@ void print_sentence_word_alternatives(Sentence sent, Boolean debugprint,
 		/* Iterate over alternatives */
 		for (ai=0; ;  ai++)
 		{
-			Boolean alt_exists = w.alternatives[ai] != NULL;
+			bool alt_exists = w.alternatives[ai] != NULL;
 
 			if (alt_exists && debugprint)
 				lgdebug(0, "   alt%d:", ai);
@@ -1289,7 +1292,7 @@ void print_sentence_word_alternatives(Sentence sent, Boolean debugprint,
 					{
 						struct tokenpos firstpos = { wt };
 
-						print_sentence_word_alternatives(sent, FALSE, NULL, &firstpos);
+						print_sentence_word_alternatives(sent, false, NULL, &firstpos);
 						if ((firstpos.wi != wi) || (firstpos.ai != ai))
 						{
 							/* We encountered this token earlier */
