@@ -1,3 +1,6 @@
+/**
+ * Encode link-grammar for solving with the SAT solver...
+ */
 #include <cstdlib>
 #include <cstdio>
 #include <cstring>
@@ -21,18 +24,19 @@ using std::endl;
 
 extern "C" {
 #include "analyze-linkage.h"
+#include "dict-file/read-dict.h"
 #include "extract-links.h"
 #include "linkage.h"
 #include "post-process.h"
 #include "preparation.h"
-#include "dict-file/read-dict.h"
+#include "utilities.h"
 }
 
 // Macro DEBUG_print is used to dump to stdout information while debugging
 #ifdef _DEBUG
 #define DEBUG_print(x) (cout << x << endl)
 #else
-#define DEBUG_print(x) (0)
+#define DEBUG_print(x) 
 #endif
 
 /*-------------------------------------------------------------------------*
@@ -1218,19 +1222,14 @@ void SATEncoder::pp_prune()
   }
 }
 
-/* TODO: replace with analyze_xxx_linkage */
-bool SATEncoder::post_process_linkage(Linkage linkage)
-{
-  Linkage_info li = analyze_thin_linkage(_sent, _opts, PP_SECOND_PASS);
-  return li.N_violations == 0;
-}
-
 /*--------------------------------------------------------------------------*
  *                         D E C O D I N G                                  *
  *--------------------------------------------------------------------------*/
 
-/* This is is almost identical to linkage_create(), except that
- * sat_extract_links is called, instead of normal extract_links.
+/* This is very similar to the api call linkage_create(), except that
+ * sat_extract_links is called, instead of normal extract_links().
+ * It would be good to refactor this and the other to make them even
+ * more similar, because right now, its confusing ...
  */
 Linkage SATEncoder::create_linkage()
 {
@@ -1242,7 +1241,7 @@ Linkage SATEncoder::create_linkage()
   linkage->word = (const char **) exalloc(linkage->num_words*sizeof(char *));
   linkage->sent = _sent;
   linkage->opts = _opts;
-  //  linkage->info = sent->link_info[k];
+  //  linkage->info = sent->link_info[k]; done later...
 
   if (_sent->parse_info) {
     Parse_info pi = _sent->parse_info;
@@ -1291,11 +1290,29 @@ Linkage SATEncoder::get_next_linkage()
   if (connected) {
     // num_connected_linkages++;
 
-    if (post_process_linkage(linkage)) {
-      cout << "Linkage PP OK" << endl;
+    // Expand the lifo array.
+    int index = _sent->num_linkages_alloced;
+    _sent->num_linkages_alloced++;
+    size_t nbytes = _sent->num_linkages_alloced * sizeof(Linkage_info);
+    _sent->link_info = (Linkage_info*) xrealloc(_sent->link_info,
+                       nbytes - sizeof(Linkage_info), nbytes);
+    Linkage_info* lifo = &_sent->link_info[index];
+
+    // Why is linkage_post_process() never called here?
+    *lifo = analyze_thin_linkage(_sent, _opts, PP_SECOND_PASS);
+    lifo->index = index;
+    linkage->info = lifo;
+
+    if (0 == lifo->N_violations) {
       _sent->num_valid_linkages++;
+      sane_linkage_morphism(_sent, index, _opts);
+    }
+
+    // sane_morphism will increment N_violations if its insane...
+    if (0 == lifo->N_violations) {
+      cout << "Linkage PP OK" << endl;
     } else {
-           cout << "Linkage PP NOT OK" << endl;
+      cout << "Linkage PP NOT OK" << endl;
     }
 
     generate_linkage_prohibiting();
@@ -1489,19 +1506,28 @@ bool SATEncoderConjunctionFreeSentences::sat_extract_links(Parse_info pi)
     if (_solver->model[_variables->linked(var->left_word, var->right_word)] != l_True)
       continue;
 
-    pi->link_array[current_link].lw = var->left_word;
-    pi->link_array[current_link].rw = var->right_word;
+    Link& clink = pi->link_array[current_link];
+    clink.lw = var->left_word;
+    clink.rw = var->right_word;
     //    pi->link_array[j].name = var->label;
 
     Connector* connector;
 
     connector = connector_new();
     connector->string = var->left_connector;
-    pi->link_array[current_link].lc = connector;
+    clink.lc = connector;
 
     connector = connector_new();
     connector->string = var->right_connector;
-    pi->link_array[current_link].rc = connector;
+    clink.rc = connector;
+
+    // Indicate the disjuncts, too.
+    // This is needed so that compute_chosen_word works correctly.
+#ifdef NO_DISJUNCT_INFO_AVAILABLE_WTF
+// XXX I think LinkVar needs to be extended to hold the disjunct
+    pi->chosen_disjuncts[clink.lw] = ld;
+    pi->chosen_disjuncts[clink.rw] = rd;
+#endif
 
     current_link++;
   }
