@@ -4,10 +4,6 @@
 #include <vector>
 #include <map>
 
-extern "C" {
-#include <link-grammar/api.h>
-}
-
 #include "guiding.hpp"
 #include "Solver.h"
 #include "trie.hpp"
@@ -54,44 +50,22 @@ static char* construct_link_label(const char* connector1, const char* connector2
   return result;
 }
 
-static bool labels_match(const char* label1, const char* label2) {
-  //  printf("Compare: %s %s\n", label1, label2);
-
-  if ((label1[0] == 'S' &&  label2[0] == 'S') &&
-      (label1[1] == 's' || label1[1] == 'p') &&
-      (label2[1] == 's' || label2[1] == 'p')) {
-    label1 += 2;
-    label2 += 2;
-  }
-
-  while(*label1 != '\0' && *label2 != '\0') {
-    if (*label1 != '*' && *label2 != '*' &&
-        *label1 != *label2)
-      return false;
-
-    label1++; label2++;
-  }
-  return true;
-}
 
 ////////////////////////////////////////////////////////////////////////////
-class Variables {
+class Variables
+{
 public:
   Variables(Sentence sent)
-    :_var(0)
-    ,_sent(sent)
+    :_sent(sent)
+    ,_link_variable_map(sent->length)
     ,_linked_variable_map(sent->length, -1)
     ,_linked_min_variable_map(sent->length, -1)
     ,_linked_max_variable_map(sent->length, -1)
-    ,_link_variable_map(sent->length)
-#ifdef USE_FAT_LINKAGES
-    ,_fat_link_variable_map(sent->length, -1)
-    ,_link_top_ww_variable_map(sent->length, -1)
-#endif /* USE_FAT_LINKAGES */
-    ,_link_top_cw_variable_map(sent->length)
-    , _link_cw_variable_map(sent->length)
     ,_thin_link_variable_map(sent->length, -1)
+    ,_link_top_cw_variable_map(sent->length)
+    ,_link_cw_variable_map(sent->length)
     ,_guiding(new CostDistanceGuiding(sent))
+    ,_var(0)
   {
   }
 
@@ -112,7 +86,8 @@ public:
    */
 
   // If guiding params are unknown, they are set do default
-  int string(const char* name) {
+  int string(const char* name)
+  {
     int var;
     if (!get_var_from_trie(name, var)) {
 #ifdef _VARS
@@ -126,7 +101,8 @@ public:
 
   // If the cost is explicitely given, guiding params are calculated
   // using the cost. Any params set earlier are overridden.
-  int string_cost(const char* name, int cost) {
+  int string_cost(const char* name, double cost)
+  {
     int var;
     var = string(name);
     _guiding->setStringParameters(var, name, cost);
@@ -232,7 +208,8 @@ public:
   // If the cost is specified, guiding params are calculated
   // using the cost. Any guiding params that are set earlier are overridden
   int link_cost(int wi, int pi, const char* ci, int wj, int pj, const char* cj,
-                int cost) {
+                double cost)
+  {
     assert(wi < wj, "Variables: link should be ordered");
     int var = link(wi, pi, ci, wj, pj, cj);
     _guiding->setLinkParameters(var, wi, ci, wj, cj, link_variable(var)->label, cost);
@@ -240,57 +217,6 @@ public:
     return var;
   }
 
-#ifdef USE_FAT_LINKAGES
-  /*
-   * The following types of variables are used for conjunction handling
-   */
-  /*
-   *                  fat_link(wi, wj)
-   * Variables that specify that there is a fat link from the word i
-   * up to the word j
-   */
-
-  // If guiding params for this variable are not set earlier, they are
-  // now set to default
-  int fat_link(int wi, int wj) {
-    assert(_sent->is_conjunction[wj] || strcmp(_sent->word[wj].alternatives[0], ",") == 0,
-           "Fat link can up only to a connective word");
-    int var;
-    if (!get_fat_link_variable(wi, wj, var)) {
-#ifdef _VARS
-      var_defs_stream << "fatlink_" << wi << "_" << wj << "\t" << var << endl;
-#endif
-      add_fatlink_variable(wi, wj, var);
-      _guiding->setFatLinkParameters(var, wi, wj);
-    }
-    assert(var != -1, "Var == -1");
-    return var;
-  }
-
-  /*
-   *                   fat_link_neighbor(w)
-   * It seems that connective words usually have fat links to at least one
-   * neighboring word. This is a definitional variable for that notion and
-   * it can positively affect the search guiding.
-   */
-  int neighbor_fat_link(int w) {
-    assert(_sent->is_conjunction[w] || strcmp(_sent->word[w].alternatives[0], ",") == 0,
-           "Only connective words can have fat links down");
-    int var;
-    char name[MAX_VARIABLE_NAME];
-    sprintf(name, "nfl_%d", w);
-    if (!get_var_from_trie(name, var)) {
-#ifdef _VARS
-      var_defs_stream << name << "\t" << var << endl;
-#endif
-      _guiding->setNeighborFatLinkParameters(var, w);
-    }
-    assert(var != -1, "Var == -1");
-    return var;
-  }
-#endif /* USE_FAT_LINKAGES */
-
-
   /*
    *             thin_link(wi, wj)
    * Variables that specify that two words are linked by a thin link
@@ -359,28 +285,6 @@ public:
     return var;
   }
 
-#ifdef USE_FAT_LINKAGES
-  /*
-   *             link_top_ww(wi, wj)
-   * Variables that specify that word wi is linked to the word wj, and
-   * wj is a top of the fat-link tree.
-   */
-
-  // If guiding params are unknown, they are set do default
-  int link_top_ww(int wi, int wj) {
-    int var;
-    if (!get_link_top_ww_variable(wi, wj, var)) {
-#ifdef _VARS
-      var_defs_stream << "link_top_ww_" << wi << "_" << wj << "\t" << var << endl;
-#endif
-      _guiding->setLinkTopWWParameters(var, wi, wj);
-    }
-    assert(var != -1, "Var == -1");
-    return var;
-  }
-#endif /* USE_FAT_LINKAGES */
-
-
 
 #ifdef _CONNECTIVITY_
   /* The following variables are deprecated */
@@ -433,12 +337,12 @@ public:
 
     std::string name;
     char* label;
+    int left_word;
+    int right_word;
+    int left_position;
+    int right_position;
     const char* left_connector;
     const char* right_connector;
-    int left_word;
-    int left_position;
-    int right_word;
-    int right_position;
   };
 
   // Returns additional info about the given link variable
@@ -487,10 +391,10 @@ public:
     }
 
     std::string name;
-    char* label;
-    const char* connector;
     int connector_word;
     int top_word;
+    char* label;
+    const char* connector;
   };
 
   // Returns additional info about the given link_top_cw variable
@@ -498,31 +402,6 @@ public:
     return _link_top_cw_variables[var];
   }
 
-#ifdef USE_FAT_LINKAGES
-  /*
-   *           fat_link(wi, wj)
-   */
-  // Returns indices of all fat-link variables
-  const std::vector<int>& fat_link_variables() const {
-    return _fat_link_variables_indices;
-  }
-
-  // Additional info about the fatlink(wi, wj) variable
-  struct FatLinkVar {
-    FatLinkVar(int down, int up)
-      : down_word(down), up_word(up) {
-    }
-
-    int down_word;
-    int up_word;
-  };
-
-  // Return additional info about the given fat-link variable
-  const FatLinkVar* fat_link_variable(int var) const {
-    return _fat_link_variables[var];
-  }
-#endif /* USE_FAT_LINKAGES */
-
   /* Pass SAT search parameters to the MiniSAT solver */
   void setVariableParameters(Solver* solver) {
     _guiding->passParametersToSolver(solver);
@@ -558,7 +437,8 @@ private:
   std::vector<LinkVar*> _link_variables;
 
   // Set this additional info
-  void add_link_variable(int i, int pi, const char* ci, int j, int pj, const char* cj, int var) {
+  void add_link_variable(int i, int pi, const char* ci, int j, int pj, const char* cj, size_t var)
+  {
     char name[MAX_VARIABLE_NAME];
     char* s = name;
     *s++ = 'l';    *s++ = 'i';     *s++ = 'n';     *s++ = 'k';
@@ -599,7 +479,7 @@ private:
   std::vector<LinkedVar*> _linked_variables;
 
   // Set the additional info
-  void add_linked_variable(int i, int j, int var) {
+  void add_linked_variable(int i, int j, size_t var) {
     if (var >= _linked_variables.size()) {
       _linked_variables.resize(var + 1, 0);
     }
@@ -613,35 +493,6 @@ private:
   // What is the number of the linked_max(i, j) variable?
   Matrix<int> _linked_max_variable_map;
 
-#ifdef USE_FAT_LINKAGES
-  /*
-   * Information about the fat_link(i, j) variables
-   */
-  // What is the number of the fatlink(wi, wj) variable?
-  Matrix<int> _fat_link_variable_map;
-
-  // What are the numbers of all fatlink(wi wj) variables?
-  std::vector<int>  _fat_link_variables_indices;
-
-  // Additional info about the fatlink(wi, wj) variable with the given number
-  std::vector<FatLinkVar*> _fat_link_variables;
-
-  // Set the additional info
-  void add_fatlink_variable(int i, int j, int var) {
-    if (var >= _fat_link_variables.size()) {
-      _fat_link_variables.resize(var + 1, 0);
-    }
-    _fat_link_variables[var] = new FatLinkVar(i, j);
-    _fat_link_variables_indices.push_back(var);
-  }
-
-  /*
-   * Information about the link_top_ww(i, j) variables
-   */
-  // What is the number of the link_top_ww(i, j) variable?
-  Matrix<int> _link_top_ww_variable_map;
-#endif /* USE_FAT_LINKAGES */
-
   /*
    * Information about the thin_link(i, j) variables
    */
@@ -662,7 +513,7 @@ private:
   std::vector<LinkTopCWVar*> _link_top_cw_variables;
 
   // Set this additional info
-  void add_link_top_cw_variable(int i, int j, int pj, const char* cj, int var) {
+  void add_link_top_cw_variable(int i, int j, int pj, const char* cj, size_t var) {
     char name[MAX_VARIABLE_NAME];
     char* s = name;
     *s++ = 'l';    *s++ = 'i';     *s++ = 'n';     *s++ = 'k'; *s++ = '_'; *s++ = 't'; *s++ = 'o'; *s++ = 'p';
@@ -699,7 +550,7 @@ private:
   Guiding* _guiding;
 
   /* Current free variable number */
-  int _var;
+  size_t _var;
 
   /* Get a variable number that has not been used before */
   int get_fresh_var(void) {
@@ -792,15 +643,6 @@ private:
     return get_2int_variable(i, j, var, _linked_max_variable_map);
   }
 
-#ifdef USE_FAT_LINKAGES
-  bool get_fat_link_variable(int i, int j, int& var) {
-    return get_2int_variable(i, j, var, _fat_link_variable_map);
-  }
-  bool get_link_top_ww_variable(int i, int j, int& var) {
-    return get_2int_variable(i, j, var, _link_top_ww_variable_map);
-  }
-#endif /* USE_FAT_LINKAGES */
-
   bool get_thin_link_variable(int i, int j, int& var) {
     return get_2int_variable(i, j, var, _thin_link_variable_map);
   }
