@@ -123,7 +123,7 @@ struct Connector_struct
     short label;
 #endif /* USE_FAT_LINKAGES */
     Connector * next;
-    const char * string;
+    const char * string;  /* The connector name, e.g. AB+ */
 
     /* Hash table next pointer, used only during pruning. */
     Connector * tableNext;
@@ -145,7 +145,7 @@ struct Disjunct_struct
     const char * string;      /* subscripted dictionary word */
     Connector *left, *right;
     double cost;
-    bool marked;
+    bool marked;              /* unmarked disjuncts get deleted */
 };
 
 typedef struct Match_node_struct Match_node;
